@@ -7,7 +7,7 @@ use Path::Tiny ();
 use Scalar::Util ();
 use Exporter 5.57 qw/import/;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 our @EXPORT    = qw(file dir file_or_dir dir_or_file);
 our @EXPORT_OK = (@Path::Tiny::EXPORT, @Path::Tiny::EXPORT_OK);
@@ -415,7 +415,12 @@ sub children {
 
 sub recurse {
   my $self = shift;
-  my %opts = (preorder => 1, depthfirst => 0, prune => 1, @_);
+  my %opts = (
+    preorder => 1,
+    depthfirst => 0,
+    prune => 1,
+    (@_ == 1 && ref $_[0] eq ref sub {}) ? (callback => $_[0]) : @_
+  );
   my $callback = $opts{callback}
     or Carp::croak "Must provide a 'callback' parameter to recurse()";
   my @queue = ($self);
